==> ingdao-0.0.6.tar.gz: lib/dataflow/invlog/web/entity/entwebreqexe.dart <==

import '../../../entity/dfbaseentity.dart';
import '../../../entity/dfdbentity.dart';
import '../../../field/dfbasefield.dart';
import '../../../field/dfdbfield.dart';
import '../../../field/dffieldtype.dart';
import '../../../control/dfconverter.dart';
import 'package:object_mapper/object_mapper.dart';
import 'webreqexefield.dart';

class WebReqExe extends DfDbEntity with WebReqExeField {
    
  WebReqExe ({String id, String webReqId, String response, int errorCode, String errorMessage}) : super(name: "log_webreqexe") {
    fId = DfDbField(entity: this, name: "id", primaryKey: true, joinKey: false, fieldType: DfFieldType.text(), value: id);
    fWebReqId = DfDbField(entity: this, name: "webreqid", primaryKey: false, joinKey: true, fieldType: DfFieldType.text(), value: webReqId);
    fCreatedAt = DfDbField(entity: this, name: "createdat", primaryKey: false, joinKey: false, fieldType: DfFieldType.datetime(), value: DateTime.now());
    fResponse = DfDbField(entity: this, name: "response", primaryKey: false, joinKey: false, fieldType: DfFieldType.text(), value: response);
    fErrorCode = DfDbField(entity: this, name: "errorcode", primaryKey: false, joinKey: false, fieldType: DfFieldType.integer(), value: errorCode);
    fErrorMessage = DfDbField(entity: this, name: "errormessage", primaryKey: false, joinKey: false, fieldType: DfFieldType.text(), value: errorMessage);
  }

  //Define the sqilite table fields available.
  //Define the fields will map back to the sqlite query executed reuslt: Map<String,dynamic>
  @override
  List<DfDbField> fields() {
     return [
       fId,
       fWebReqId,
       fCreatedAt,
       fResponse,
       fErrorCode,
       fErrorMessage,
     ];
  }

  @override
  DfBaseEntity<DfBaseField> newInstance() {
    return WebReqExe();
  }

  @override
  Type myType() {
    return WebReqExe;
  }

  @override
  DfBaseEntity<DfDbField> jsonToObject(Mapper map) {
    return map.toObject<WebReqExe>();
  }
}

==> ingdao-0.0.7.tar.gz: lib/dataflow/invlog/web/entity/entwebreqexe.dart <==

import '../../../entity/dfbaseentity.dart';
import '../../../entity/dfdbentity.dart';
import '../../../field/dfbasefield.dart';
import '../../../field/dfdbfield.dart';
import '../../../field/dffieldtype.dart';
import 'webreqexefield.dart';
import '../../../control/dfquery.dart';

class WebReqExe extends DfDbEntity with WebReqExeField {
    
  WebReqExe ({String id, String webReqId, String response, int errorCode, String errorMessage}) : super(name: "log_webreqexe") {
    fId = DfDbField(entity: this, name: "id", primaryKey: true, joinKey: false, fieldType: DfFieldType.text(), value: id);
    fWebReqId = DfDbField(entity: this, name: "webreqid", primaryKey: false, joinKey: true, fieldType: DfFieldType.text(), value: webReqId);
    fCreatedAt = DfDbField(entity: this, name: "createdat", primaryKey: false, joinKey: false, fieldType: DfFieldType.datetime(), value: DateTime.now());
    fResponse = DfDbField(entity: this, name: "response", primaryKey: false, joinKey: false, fieldType: DfFieldType.text(), value: response);
    fErrorCode = DfDbField(entity: this, name: "errorcode", primaryKey: false, joinKey: false, fieldType: DfFieldType.integer(), value: errorCode);
    fErrorMessage = DfDbField(entity: this, name: "errormessage", primaryKey: false, joinKey: false, fieldType: DfFieldType.text(), value: errorMessage);
  }

  //Define the sqilite table fields available.
  //Define the fields will map back to the sqlite query executed reuslt: Map<String,dynamic>
  @override
  List<DfDbField> fields() {
     return [
       fId,
       fWebReqId,
       fCreatedAt,
       fResponse,
       fErrorCode,
       fErrorMessage,
     ];
  }

  @override
  DfBaseEntity<DfBaseField> newInstance() {
    return WebReqExe();
  }

  @override
  DfBaseEntity<DfDbField> jsonToObject(DfQueryPurpose purpose, map) {
    return map.toObject<WebReqExe>();
  }
}
